#
# Conditional build:
%bcond_with	openct		# use OpenCT instead of PC/SC for reader access
%bcond_without	openpace	# OpenPACE support
#
Summary:	OpenSC library - for accessing SmartCard devices using PC/SC Lite
Summary(pl.UTF-8):	Biblioteka OpenSC - do korzystania z kart procesorowych przy użyciu PC/SC Lite
Name:		opensc
Version:	0.17.0
Release:	1
License:	LGPL v2.1+
Group:		Applications
#Source0Download: https://github.com/OpenSC/OpenSC/releases
Source0:	https://github.com/OpenSC/OpenSC/releases/download/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	fc502ed7753f950b8e2a18a476d0cd52
URL:		https://github.com/OpenSC/OpenSC/wiki
BuildRequires:	autoconf >= 2.60
BuildRequires:	automake >= 1:1.10
BuildRequires:	docbook-style-xsl
BuildRequires:	libltdl-devel
BuildRequires:	libtool >= 1:1.4.2-9
BuildRequires:	libxslt-progs
%{?with_openct:BuildRequires:	openct-devel}
%{?with_openpace:BuildRequires:	openpace-devel >= 0.9}
BuildRequires:	openssl-devel >= 0.9.7d
%{!?with_openct:BuildRequires:	pcsc-lite-devel >= 1.8.22}
BuildRequires:	pkgconfig >= 1:0.9.0
BuildRequires:	readline-devel
BuildRequires:	rpmbuild(macros) >= 1.364
BuildRequires:	zlib-devel
Requires:	filesystem >= 4.0-28
%{?with_openpace:Requires:	openpace >= 0.9}
%{!?with_openct:Requires:	pcsc-lite-libs >= 1.8.22}
Obsoletes:	browser-plugin-opensc
Obsoletes:	mozilla-plugin-opensc
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# datadir is used for config files and (editable) profiles
%define		_datadir	/etc
%define		_sysconfdir	/etc/opensc

%description
libopensc is a library for accessing SmartCard devices using PC/SC
Lite middleware package. It is also the core library of the OpenSC
project. Basic functionality (e.g. SELECT FILE, READ BINARY) should
work on any ISO 7816-4 compatible SmartCard. Encryption and decryption
using private keys on the SmartCard is at the moment possible only
with PKCS#15 compatible cards, such as the FINEID (Finnish Electronic
IDentity) card manufactured by Setec.

%description -l pl.UTF-8
libopensc to biblioteka do korzystania z kart procesorowych przy
użyciu pakietu warstwy pośredniej PC/SC Lite. Jest to także podstawowa
biblioteka projektu OpenSC. Podstawowa funkcjonalność (np. SELECT
FILE, READ BINARY) powinna działać także z dowolną kartą procesorową
zgodną z ISO-7816-4. Szyfrowanie i odszyfrowywanie przy użyciu
prywatnych kluczy na karcie na razie jest możliwe tylko przy użyciu
kart kompatybilnych z PKCS#16, takich jak FINEID (Finnish Electronic
IDentity) produkowanych przez Setec.

%package devel
Summary:	OpenSC development files
Summary(pl.UTF-8):	Pliki dla programistów używających OpenSC
Group:		Development/Tools
Requires:	%{name} = %{version}-%{release}
Requires:	libltdl-devel
%{?with_openct:Requires:	openct-devel}
Requires:	openssl-devel >= 0.9.7d
%{!?with_openct:Requires:	pcsc-lite-devel >= 1.8.22}
Requires:	zlib-devel

%description devel
OpenSC development files.

%description devel -l pl.UTF-8
Pliki dla programistów używających OpenSC.

%package static
Summary:	Static OpenSC library
Summary(pl.UTF-8):	Bibloteka statyczna OpenSC
Group:		Development/Tools
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static OpenSC library.

%description static -l pl.UTF-8
Biblioteka statyczna OpenSC.

%package -n bash-completion-opensc
Summary:	Bash completion for OpenSC commands
Summary(pl.UTF-8):	Bashowe uzupełnianie parametrów poleceń OpenSC
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}

%description -n bash-completion-opensc
Bash completion for OpenSC commands.

%description -n bash-completion-opensc -l pl.UTF-8
Bashowe uzupełnianie parametrów poleceń OpenSC.

%prep
%setup -q

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{?with_openct:--enable-openct --disable-pcsc} \
	%{!?with_openct:--enable-pcsc --disable-openct} \
	%{!?with_openpace:--disable-openpace} \
	--disable-silent-rules \
	--enable-doc \
	--with-pcsc-provider=%{_libdir}/libpcsclite.so.1

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_sysconfdir},%{_libdir}/pkcs11}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	completiondir=/etc/bash_completion.d

# not needed (dlopened by soname)
%{__rm} $RPM_BUILD_ROOT%{_libdir}/{onepin-opensc-pkcs11,opensc-pkcs11,pkcs11-spy}.la
# API not exported
%{__rm} $RPM_BUILD_ROOT%{_libdir}/lib{opensc,smm-local}.la

%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc NEWS README doc/tools/tools.html
%attr(755,root,root) %{_bindir}/cardos-tool
%attr(755,root,root) %{_bindir}/cryptoflex-tool
%attr(755,root,root) %{_bindir}/dnie-tool
%attr(755,root,root) %{_bindir}/eidenv
%attr(755,root,root) %{_bindir}/gids-tool
%attr(755,root,root) %{_bindir}/iasecc-tool
%attr(755,root,root) %{_bindir}/netkey-tool
%attr(755,root,root) %{_bindir}/npa-tool
%attr(755,root,root) %{_bindir}/openpgp-tool
%attr(755,root,root) %{_bindir}/opensc-explorer
%attr(755,root,root) %{_bindir}/opensc-tool
%attr(755,root,root) %{_bindir}/piv-tool
%attr(755,root,root) %{_bindir}/pkcs11-tool
%attr(755,root,root) %{_bindir}/pkcs15-crypt
%attr(755,root,root) %{_bindir}/pkcs15-init
%attr(755,root,root) %{_bindir}/pkcs15-tool
%attr(755,root,root) %{_bindir}/sc-hsm-tool
%attr(755,root,root) %{_bindir}/westcos-tool
%attr(755,root,root) %{_libdir}/libopensc.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libopensc.so.5
%attr(755,root,root) %{_libdir}/libsmm-local.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libsmm-local.so.5
# PKCS11 modules
%attr(755,root,root) %{_libdir}/onepin-opensc-pkcs11.so
%attr(755,root,root) %{_libdir}/opensc-pkcs11.so
%attr(755,root,root) %{_libdir}/pkcs11-spy.so
%attr(755,root,root) %{_libdir}/pkcs11/onepin-opensc-pkcs11.so
%attr(755,root,root) %{_libdir}/pkcs11/opensc-pkcs11.so
%attr(755,root,root) %{_libdir}/pkcs11/pkcs11-spy.so
%dir %{_datadir}/opensc
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/opensc.conf
%config(noreplace) %verify(not md5 mtime size) %{_datadir}/opensc/*.profile
%if %{with openpace}
/etc/eac/cvc/DESRCACC100001
%endif
%{_mandir}/man1/cardos-tool.1*
%{_mandir}/man1/cryptoflex-tool.1*
%{_mandir}/man1/dnie-tool.1*
%{_mandir}/man1/eidenv.1*
%{_mandir}/man1/gids-tool.1*
%{_mandir}/man1/iasecc-tool.1*
%{_mandir}/man1/netkey-tool.1*
%{_mandir}/man1/npa-tool.1*
%{_mandir}/man1/openpgp-tool.1*
%{_mandir}/man1/opensc-explorer.1*
%{_mandir}/man1/opensc-tool.1*
%{_mandir}/man1/piv-tool.1*
%{_mandir}/man1/pkcs11-tool.1*
%{_mandir}/man1/pkcs15-crypt.1*
%{_mandir}/man1/pkcs15-init.1*
%{_mandir}/man1/pkcs15-tool.1*
%{_mandir}/man1/sc-hsm-tool.1*
%{_mandir}/man1/westcos-tool.1*
%{_mandir}/man5/pkcs15-profile.5*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libopensc.so
%attr(755,root,root) %{_libdir}/libsmm-local.so
%{_pkgconfigdir}/opensc-pkcs11.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libopensc.a

%files -n bash-completion-opensc
%defattr(644,root,root,755)
/etc/bash_completion.d/cardos-tool
/etc/bash_completion.d/cryptoflex-tool
/etc/bash_completion.d/dnie-tool
/etc/bash_completion.d/eidenv
/etc/bash_completion.d/gids-tool
/etc/bash_completion.d/iasecc-tool
/etc/bash_completion.d/netkey-tool
/etc/bash_completion.d/openpgp-tool
/etc/bash_completion.d/opensc-explorer
/etc/bash_completion.d/opensc-tool
/etc/bash_completion.d/piv-tool
/etc/bash_completion.d/pkcs11-tool
/etc/bash_completion.d/pkcs15-crypt
/etc/bash_completion.d/pkcs15-init
/etc/bash_completion.d/pkcs15-tool
/etc/bash_completion.d/sc-hsm-tool
/etc/bash_completion.d/westcos-tool
%changelog
* Sun Nov 26 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/opensc.git;a=log;h=master

* Sun Nov 26 2017 Jakub Bogusz <qboosh@pld-linux.org> 46bcb39
- updated to 0.17.0
- removed outdated pc patch

* Tue Oct 18 2016 Jan Rękorajski <baggins@pld-linux.org> 6b93b76
- rebuild with readline 7.0
- release 2 (by relup.sh)

* Sat Aug 27 2016 Jakub Bogusz <qboosh@pld-linux.org> 112cff3
- updated to 0.16.0 (note: new sonames)
- removed obsolete missing patch

* Sun Jan 31 2016 Jakub Bogusz <qboosh@pld-linux.org> 4735910
- updated to 0.15.0
- added missing patch (missing file taken from git)

* Sat Aug 23 2014 Jakub Bogusz <qboosh@pld-linux.org> ef886f9
- updated to 0.14.0

* Mon Dec 30 2013 Jakub Bogusz <qboosh@pld-linux.org> 4f1bc56
- new URLs, updated to 0.13.0
- %{_libdir}/pkcs11 dir is owned by filesystem now
- added pc patch (fix and install .pc file), package .pc file instead of .la file

* Sat Apr 28 2012 Jan Rękorajski <baggins@pld-linux.org> 3d10579
- fixed install

* Sat Apr 28 2012 Jan Rękorajski <baggins@pld-linux.org> b8105e4
- looks like just parallel make problem?

* Sat Apr 28 2012 Jan Rękorajski <baggins@pld-linux.org> 70be04b
- create dir for make install

* Sat Apr 28 2012 Jan Rękorajski <baggins@pld-linux.org> 62e1cc6
- rel 2
- drop initramfs package, it was never properly tested, never really updated
  and initramfs-tools functionality is obsoleted by dracut

* Tue Sep 20 2011 Jacek Konieczny <jajcus@pld-linux.org> a2fdd8f
- openldap is not required any more

* Wed Aug 10 2011 Jakub Bogusz <qboosh@pld-linux.org> 80bde4f
- updated to 0.12.2

* Sat May 28 2011 Jakub Bogusz <qboosh@pld-linux.org> 53aad45
- updated to 0.12.1

* Wed Mar 16 2011 Elan Ruusamäe <glen@pld-linux.org> 0a3c046
- invert openct bcond, it is not usable, old and segfaults
- see also http://www.opensc-project.org/pipermail/opensc-announce/2010-December/000033.html

* Sat Jan 08 2011 Jakub Bogusz <qboosh@pld-linux.org> 28044ea
- cleanup
- note: browser plugin is gone

* Sat Jan 08 2011 Jakub Bogusz <qboosh@pld-linux.org> 455ac4e
- updated to 0.12.0
- removed obsolete assuan-2,pcsc patches
- libopensc API no longer public

* Mon Aug 09 2010 Jakub Bogusz <qboosh@pld-linux.org> c9f4880
- time to move to new libassuan - added libassuan-2 patch from upstream trac
- added pcsc patch to build with current pcsc
- package westcos-tool

* Fri May 14 2010 sparky <sparky@pld-linux.org> d740a4d
- replaced BR: libassuan-devel >= 1:0.6.0 with BR: libassuan1-devel >= 0.6.0
- BR: libxslt-progs

* Mon Apr 12 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> b725c00
- release 2

* Fri Feb 26 2010 zbyniu <zbyniu@pld-linux.org> 239c495
- up to 0.11.13

